<?php

namespace Goal\Goal\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Goal\Goal\Interfaces\GoalRepositoryInterface;
use Goal\Goal\Repositories\Presenter\GoalItemTransformer;

/**
 * Pubic API controller class.
 */
class GoalPublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Goal\Goal\Interfaces\GoalRepositoryInterface $goal
     *
     * @return type
     */
    public function __construct(GoalRepositoryInterface $goal)
    {
        $this->repository = $goal;
        parent::__construct();
    }

    /**
     * Show goal's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $goals = $this->repository
            ->setPresenter('\\Goal\\Goal\\Repositories\\Presenter\\GoalListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $goals['code'] = 2000;
        return response()->json($goals)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show goal.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $goal = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($goal)) {
            $goal         = $this->itemPresenter($module, new GoalItemTransformer);
            $goal['code'] = 2001;
            return response()->json($goal)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
