<?php

namespace Goal\Goal\Http\Controllers;

use App\Http\Controllers\UserController as BaseController;
use Form;
use Goal\Goal\Http\Requests\GoalRequest;
use Goal\Goal\Interfaces\GoalRepositoryInterface;
use Goal\Goal\Models\Goal;

class GoalUserController extends BaseController
{
    /**
     * Initialize goal controller.
     *
     * @param type GoalRepositoryInterface $goal
     *
     * @return type
     */
    public function __construct(GoalRepositoryInterface $goal)
    {
        $this->repository = $goal;
        $this->repository
                ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
                ->pushCriteria(new \Goal\Goal\Repositories\Criteria\GoalUserCriteria());
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(GoalRequest $request)
    {
        $goals = $this->repository->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();

        $this->theme->prependTitle(trans('goal::goal.names'));

        return $this->theme->of('goal::user.goal.index', compact('goals'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param Goal $goal
     *
     * @return Response
     */
    public function show(GoalRequest $request, Goal $goal)
    {
        Form::populate($goal);

        return $this->theme->of('goal::user.goal.show', compact('goal'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(GoalRequest $request)
    {

        $goal = $this->repository->newInstance([]);
        Form::populate($goal);

        $this->theme->prependTitle(trans('goal::goal.names'));
        return $this->theme->of('goal::user.goal.create', compact('goal'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(GoalRequest $request)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $goal = $this->repository->create($attributes);

            return redirect(trans_url('/user/goal/goal'))
                -> with('message', trans('messages.success.created', ['Module' => trans('goal::goal.name')]))
                -> with('code', 201);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param Goal $goal
     *
     * @return Response
     */
    public function edit(GoalRequest $request, Goal $goal)
    {

        Form::populate($goal);
        $this->theme->prependTitle(trans('goal::goal.names'));

        return $this->theme->of('goal::user.goal.edit', compact('goal'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param Goal $goal
     *
     * @return Response
     */
    public function update(GoalRequest $request, Goal $goal)
    {
        try {
            $this->repository->update($request->all(), $goal->getRouteKey());

            return redirect(trans_url('/user/goal/goal'))
                ->with('message', trans('messages.success.updated', ['Module' => trans('goal::goal.name')]))
                ->with('code', 204);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(GoalRequest $request, Goal $goal)
    {
        try {
            $this->repository->delete($goal->getRouteKey());
            return redirect(trans_url('/user/goal/goal'))
                ->with('message', trans('messages.success.deleted', ['Module' => trans('goal::goal.name')]))
                ->with('code', 204);

        } catch (Exception $e) {

            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);

        }
    }
}
