<?php

namespace Goal\Goal\Http\Controllers;
use Litepie\Goal\Http\Requests\GoalRequest;
use Litepie\Goal\Models\Goal;

trait GoalWorkflow {
	
    /**
     * Workflow controller function for goal.
     *
     * @param Model   $goal
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(GoalRequest $request, Goal $goal, $step)
    {

        try {

            $goal->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('goal::goal.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/goal/goal/' . $goal->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/goal/goal/' . $goal->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for goal.
     *
     * @param Model   $goal
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Goal $goal, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $goal->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('goal::goal.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('goal::admin.goal.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('goal::admin.goal.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('goal::admin.goal.message', $data)->render();

        }

    }
}