<?php

namespace Goal\Goal\Policies;

use App\User;
use Goal\Goal\Models\Goal;

class GoalPolicy
{

    /**
     * Determine if the given user can view the goal.
     *
     * @param User $user
     * @param Goal $goal
     *
     * @return bool
     */
    public function view(User $user, Goal $goal)
    {
        if ($user->canDo('goal.goal.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $goal->user_id;
    }

    /**
     * Determine if the given user can create a goal.
     *
     * @param User $user
     * @param Goal $goal
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('goal.goal.create');
    }

    /**
     * Determine if the given user can update the given goal.
     *
     * @param User $user
     * @param Goal $goal
     *
     * @return bool
     */
    public function update(User $user, Goal $goal)
    {
        if ($user->canDo('goal.goal.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $goal->user_id;
    }

    /**
     * Determine if the given user can delete the given goal.
     *
     * @param User $user
     * @param Goal $goal
     *
     * @return bool
     */
    public function destroy(User $user, Goal $goal)
    {
        if ($user->canDo('goal.goal.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $goal->user_id;
    }

    /**
     * Determine if the given user can verify the given goal.
     *
     * @param User $user
     * @param Goal $goal
     *
     * @return bool
     */
    public function verify(User $user, Goal $goal)
    {
        if ($user->canDo('goal.goal.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('goal.goal.verify') 
        && $user->is('manager')
        && $goal->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given goal.
     *
     * @param User $user
     * @param Goal $goal
     *
     * @return bool
     */
    public function approve(User $user, Goal $goal)
    {
        if ($user->canDo('goal.goal.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
