<?php

namespace Goal\Goal\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Goal\Goal\Models\Goal;

class GoalAction
{
    /**
     * Perform the complete action.
     *
     * @param Goal $goal
     *
     * @return Goal
     */
    public function complete(Goal $goal)
    {
        try {
            $goal->status = 'complete';
            return $goal->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Goal $goal
     *
     * @return Goal
     */public function verify(Goal $goal)
    {
        try {
            $goal->status = 'verify';
            return $goal->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Goal $goal
     *
     * @return Goal
     */public function approve(Goal $goal)
    {
        try {
            $goal->status = 'approve';
            return $goal->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Goal $goal
     *
     * @return Goal
     */public function publish(Goal $goal)
    {
        try {
            $goal->status = 'publish';
            return $goal->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Goal $goal
     *
     * @return Goal
     */
    public function archive(Goal $goal)
    {
        try {
            $goal->status = 'archive';
            return $goal->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Goal $goal
     *
     * @return Goal
     */
    public function unpublish(Goal $goal)
    {
        try {
            $goal->status = 'unpublish';
            return $goal->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
