<?php

namespace Goal\Goal\Workflow;

use Goal\Goal\Models\Goal;
use Validator;

class GoalValidator
{

    /**
     * Determine if the given goal is valid for complete status.
     *
     * @param Goal $goal
     *
     * @return bool / Validator
     */
    public function complete(Goal $goal)
    {
        return Validator::make($goal->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given goal is valid for verify status.
     *
     * @param Goal $goal
     *
     * @return bool / Validator
     */
    public function verify(Goal $goal)
    {
        return Validator::make($goal->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given goal is valid for approve status.
     *
     * @param Goal $goal
     *
     * @return bool / Validator
     */
    public function approve(Goal $goal)
    {
        return Validator::make($goal->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given goal is valid for publish status.
     *
     * @param Goal $goal
     *
     * @return bool / Validator
     */
    public function publish(Goal $goal)
    {
        return Validator::make($goal->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given goal is valid for archive status.
     *
     * @param Goal $goal
     *
     * @return bool / Validator
     */
    public function archive(Goal $goal)
    {
        return Validator::make($goal->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given goal is valid for unpublish status.
     *
     * @param Goal $goal
     *
     * @return bool / Validator
     */
    public function unpublish(Goal $goal)
    {
        return Validator::make($goal->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
